==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/OsProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.OsType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specifies the operating system settings for the virtual machine.
 * @property adminPassword Gets or sets administrator password.
 * @property adminUsername Gets or sets administrator username.
 * @property computerName Gets or sets computer name.
 * @property guestId Gets or sets the guestId.
 * @property linuxConfiguration Specifies the linux configuration for update management.
 * @property osType Gets or sets the type of the os.
 * @property windowsConfiguration Specifies the windows configuration for update management.
 */
public data class OsProfileArgs(
    public val adminPassword: Output<String>? = null,
    public val adminUsername: Output<String>? = null,
    public val computerName: Output<String>? = null,
    public val guestId: Output<String>? = null,
    public val linuxConfiguration: Output<OsProfileLinuxConfigurationArgs>? = null,
    public val osType: Output<Either<String, OsType>>? = null,
    public val windowsConfiguration: Output<OsProfileWindowsConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs.builder()
            .adminPassword(adminPassword?.applyValue({ args0 -> args0 }))
            .adminUsername(adminUsername?.applyValue({ args0 -> args0 }))
            .computerName(computerName?.applyValue({ args0 -> args0 }))
            .guestId(guestId?.applyValue({ args0 -> args0 }))
            .linuxConfiguration(
                linuxConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .osType(
                osType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .windowsConfiguration(
                windowsConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OsProfileArgs].
 */
@PulumiTagMarker
public class OsProfileArgsBuilder internal constructor() {
    private var adminPassword: Output<String>? = null

    private var adminUsername: Output<String>? = null

    private var computerName: Output<String>? = null

    private var guestId: Output<String>? = null

    private var linuxConfiguration: Output<OsProfileLinuxConfigurationArgs>? = null

    private var osType: Output<Either<String, OsType>>? = null

    private var windowsConfiguration: Output<OsProfileWindowsConfigurationArgs>? = null

    /**
     * @param value Gets or sets administrator password.
     */
    @JvmName("nlxqovaephkoyren")
    public suspend fun adminPassword(`value`: Output<String>) {
        this.adminPassword = value
    }

    /**
     * @param value Gets or sets administrator username.
     */
    @JvmName("ktddvtrparoqofyg")
    public suspend fun adminUsername(`value`: Output<String>) {
        this.adminUsername = value
    }

    /**
     * @param value Gets or sets computer name.
     */
    @JvmName("ynhmmgmwfqprcwmi")
    public suspend fun computerName(`value`: Output<String>) {
        this.computerName = value
    }

    /**
     * @param value Gets or sets the guestId.
     */
    @JvmName("kqmmnwknextoijxb")
    public suspend fun guestId(`value`: Output<String>) {
        this.guestId = value
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("qbfrhlfsqaesjxbo")
    public suspend fun linuxConfiguration(`value`: Output<OsProfileLinuxConfigurationArgs>) {
        this.linuxConfiguration = value
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("pvoabtlcnnrawcqf")
    public suspend fun osType(`value`: Output<Either<String, OsType>>) {
        this.osType = value
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("ehctbtlkbqucolpj")
    public suspend fun windowsConfiguration(`value`: Output<OsProfileWindowsConfigurationArgs>) {
        this.windowsConfiguration = value
    }

    /**
     * @param value Gets or sets administrator password.
     */
    @JvmName("vlidmlhhiwdrjglw")
    public suspend fun adminPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adminPassword = mapped
    }

    /**
     * @param value Gets or sets administrator username.
     */
    @JvmName("qosisgivtuilplte")
    public suspend fun adminUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adminUsername = mapped
    }

    /**
     * @param value Gets or sets computer name.
     */
    @JvmName("hqewivoogduyjynj")
    public suspend fun computerName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computerName = mapped
    }

    /**
     * @param value Gets or sets the guestId.
     */
    @JvmName("onhtyfjuafsqjpgd")
    public suspend fun guestId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.guestId = mapped
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("omqpabnucycemqdl")
    public suspend fun linuxConfiguration(`value`: OsProfileLinuxConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linuxConfiguration = mapped
    }

    /**
     * @param argument Specifies the linux configuration for update management.
     */
    @JvmName("tcsoyivsdjspkjpx")
    public suspend
    fun linuxConfiguration(argument: suspend OsProfileLinuxConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileLinuxConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.linuxConfiguration = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("jqyichidhfwiaelh")
    public suspend fun osType(`value`: Either<String, OsType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("csqqemixcvbufmah")
    public fun osType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("eogytbokwoptheul")
    public fun osType(`value`: OsType) {
        val toBeMapped = Either.ofRight<String, OsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("smknfjpbuyleeccx")
    public suspend fun windowsConfiguration(`value`: OsProfileWindowsConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsConfiguration = mapped
    }

    /**
     * @param argument Specifies the windows configuration for update management.
     */
    @JvmName("coqqbvshksskidvv")
    public suspend
    fun windowsConfiguration(argument: suspend OsProfileWindowsConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileWindowsConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.windowsConfiguration = mapped
    }

    internal fun build(): OsProfileArgs = OsProfileArgs(
        adminPassword = adminPassword,
        adminUsername = adminUsername,
        computerName = computerName,
        guestId = guestId,
        linuxConfiguration = linuxConfiguration,
        osType = osType,
        windowsConfiguration = windowsConfiguration,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/OsProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.OsType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specifies the operating system settings for the virtual machine.
 * @property adminPassword Gets or sets administrator password.
 * @property adminUsername Gets or sets administrator username.
 * @property computerName Gets or sets computer name.
 * @property guestId Gets or sets the guestId.
 * @property linuxConfiguration Specifies the linux configuration for update management.
 * @property osType Gets or sets the type of the os.
 * @property windowsConfiguration Specifies the windows configuration for update management.
 */
public data class OsProfileArgs(
    public val adminPassword: Output<String>? = null,
    public val adminUsername: Output<String>? = null,
    public val computerName: Output<String>? = null,
    public val guestId: Output<String>? = null,
    public val linuxConfiguration: Output<OsProfileLinuxConfigurationArgs>? = null,
    public val osType: Output<Either<String, OsType>>? = null,
    public val windowsConfiguration: Output<OsProfileWindowsConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.OsProfileArgs.builder()
            .adminPassword(adminPassword?.applyValue({ args0 -> args0 }))
            .adminUsername(adminUsername?.applyValue({ args0 -> args0 }))
            .computerName(computerName?.applyValue({ args0 -> args0 }))
            .guestId(guestId?.applyValue({ args0 -> args0 }))
            .linuxConfiguration(
                linuxConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .osType(
                osType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .windowsConfiguration(
                windowsConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OsProfileArgs].
 */
@PulumiTagMarker
public class OsProfileArgsBuilder internal constructor() {
    private var adminPassword: Output<String>? = null

    private var adminUsername: Output<String>? = null

    private var computerName: Output<String>? = null

    private var guestId: Output<String>? = null

    private var linuxConfiguration: Output<OsProfileLinuxConfigurationArgs>? = null

    private var osType: Output<Either<String, OsType>>? = null

    private var windowsConfiguration: Output<OsProfileWindowsConfigurationArgs>? = null

    /**
     * @param value Gets or sets administrator password.
     */
    @JvmName("nfakdhydugcuuqfm")
    public suspend fun adminPassword(`value`: Output<String>) {
        this.adminPassword = value
    }

    /**
     * @param value Gets or sets administrator username.
     */
    @JvmName("fjicigakjbwhuyte")
    public suspend fun adminUsername(`value`: Output<String>) {
        this.adminUsername = value
    }

    /**
     * @param value Gets or sets computer name.
     */
    @JvmName("sbfmrbpkmrpmoosx")
    public suspend fun computerName(`value`: Output<String>) {
        this.computerName = value
    }

    /**
     * @param value Gets or sets the guestId.
     */
    @JvmName("qvsdagmwuywpjiwc")
    public suspend fun guestId(`value`: Output<String>) {
        this.guestId = value
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("xxvwagymeyvslgsq")
    public suspend fun linuxConfiguration(`value`: Output<OsProfileLinuxConfigurationArgs>) {
        this.linuxConfiguration = value
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("wyukjrmfmsfrqvdo")
    public suspend fun osType(`value`: Output<Either<String, OsType>>) {
        this.osType = value
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("fsqpmtmsmxajemvq")
    public suspend fun windowsConfiguration(`value`: Output<OsProfileWindowsConfigurationArgs>) {
        this.windowsConfiguration = value
    }

    /**
     * @param value Gets or sets administrator password.
     */
    @JvmName("jpdqrfodynobbsjo")
    public suspend fun adminPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adminPassword = mapped
    }

    /**
     * @param value Gets or sets administrator username.
     */
    @JvmName("qlsdevvdijdflvhm")
    public suspend fun adminUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adminUsername = mapped
    }

    /**
     * @param value Gets or sets computer name.
     */
    @JvmName("bfrcmnplbxuagcgv")
    public suspend fun computerName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computerName = mapped
    }

    /**
     * @param value Gets or sets the guestId.
     */
    @JvmName("slqufrgvwwtoljjr")
    public suspend fun guestId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.guestId = mapped
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("ldbxxcvddlocgcxv")
    public suspend fun linuxConfiguration(`value`: OsProfileLinuxConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linuxConfiguration = mapped
    }

    /**
     * @param argument Specifies the linux configuration for update management.
     */
    @JvmName("raogjytlginhykon")
    public suspend
    fun linuxConfiguration(argument: suspend OsProfileLinuxConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileLinuxConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.linuxConfiguration = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("yimfghspjjjjlbdv")
    public suspend fun osType(`value`: Either<String, OsType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("hwgtvlqpppsvmqlp")
    public fun osType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Gets or sets the type of the os.
     */
    @JvmName("xnhyojrsgksyhcbg")
    public fun osType(`value`: OsType) {
        val toBeMapped = Either.ofRight<String, OsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.osType = mapped
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("qtcsihksmeyreatw")
    public suspend fun windowsConfiguration(`value`: OsProfileWindowsConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsConfiguration = mapped
    }

    /**
     * @param argument Specifies the windows configuration for update management.
     */
    @JvmName("sehmuqgelupojhal")
    public suspend
    fun windowsConfiguration(argument: suspend OsProfileWindowsConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileWindowsConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.windowsConfiguration = mapped
    }

    internal fun build(): OsProfileArgs = OsProfileArgs(
        adminPassword = adminPassword,
        adminUsername = adminUsername,
        computerName = computerName,
        guestId = guestId,
        linuxConfiguration = linuxConfiguration,
        osType = osType,
        windowsConfiguration = windowsConfiguration,
    )
}
